dnsimple
    * ``auth_token`` Specify api token for authentication

    * ``auth_username`` Specify email address for authentication

    * ``auth_password`` Specify password for authentication

    * ``auth_2fa`` Specify two-factor auth token (otp) to use with email/password authentication
